<?php
class Custom_Payment_Gateway extends WC_Payment_Gateway
{
    private $app_key;
    private $api_url;
    private $digital;
    public function __construct()
    {
        $this->id = 'sobar_payment';
        $this->icon = apply_filters('woocommerce_pay_icon', plugins_url('assets/images/credit-cards2.png', __FILE__));
        $this->method_title = 'Sobar Pay';
        $this->method_description = 'A payment gateway that sends your customers to Sobar Pay';
        $this->has_fields = true;

        $this->supports = array(
            'products'
        );

        $this->init_form_fields();
        $this->init_settings();

        $this->title = $this->get_option('title');
        $this->description = $this->get_option('description');
        $this->enabled = $this->get_option('enabled');
        $this->app_key = $this->get_option('app_key');
        $this->api_url = 'https://sobarpay.com';
        $this->digital = $this->get_option('digital');
        add_action('woocommerce_update_options_payment_gateways_' . $this->id, array($this, 'process_admin_options'));
        add_action('wp_enqueue_scripts', array($this, 'payment_scripts'));
        add_action('wp_sobarpay_payment_process', array($this, 'process_payment'));
    }

    public function init_form_fields()
    {
        $this->form_fields = array(
            'enabled' => array(
                'title' => 'Enable/Disable',
                'type' => 'checkbox',
                'label' => 'Enable Sobar Pay',
                'default' => 'yes'
            ),
            'title' => array(
                'title' => 'Title',
                'type' => 'text',
                'description' => 'This controls the title displayed to the user during checkout.',
                'default' => 'Touch Payment gateway'
            ),
            'description' => array(
                'title' => 'Description',
                'type' => 'textarea',
                'description' => 'This controls the description displayed to the user during checkout.',
                'default' => 'Pay with Sobar Pay Payment gateway.'
            ),
            'app_key' => array(
                'title' => 'App Key',
                'type' => 'text',
                'description' => 'Enter the app key for API authentication.',
                'default' => '',
            ),

            'digital' => array(
                'title' => 'Digital Product',
                'type' => 'checkbox',
                'label' => ' If you are providing digital product then you can use this option. It will mark order as complete as soon as user paid.',
                'default' => 'no'
            ),
        );
    }
    public function payment_scripts()
    {
        if (is_checkout()) {
            wp_enqueue_style('sobar_payment-style', plugins_url('assets/css/style.css', __FILE__));
            wp_enqueue_script('worldpay-jquery-min', 'https://ajax.googleapis.com/ajax/libs/jquery/3.4.1/jquery.min.js', array('jquery'));
            wp_enqueue_script('worldpay-bootstrap-min', 'https://maxcdn.bootstrapcdn.com/bootstrap/3.4.1/js/bootstrap.min.js', array('jquery'));
            wp_enqueue_style('worldpay-script-bootstrap', 'https://maxcdn.bootstrapcdn.com/bootstrap/3.4.1/css/bootstrap.min.css');
        }
    }

    public function process_payment($order_id)
    {
        global $woocommerce;

        $order = wc_get_order($order_id);
        //Prepare success and cancel URLs
        $success_url = add_query_arg('custom-payment-callback', '1', $this->get_return_url($order));
        $cancel_url = add_query_arg('custom-payment-callback-cancel', '1', $this->get_return_url($order));



        // if (isset($parsed_response['host_url'])) {

        foreach ($order->get_items() as $item_id => $item) {
            $product[] = [
                'product_name' => $item->get_name(),
                'product_url' => $item->get_product()->get_permalink(),
                'quantity' => $item->get_quantity(),
                'amount' => $item->get_total(),
            ];
        }

        $field = [
            'firstName' => $order->get_billing_first_name(),
            'lastName' => $order->get_billing_last_name(),
            'phoneNumber' => $order->get_billing_phone(),
            'email' => $order->get_billing_email(),
            'successUrl' => $success_url,
            'cancelUrl' => $cancel_url,
            'address1' => $order->get_billing_address_1(),
            'address2' => $order->get_billing_address_2(),
            'postalCode' => $order->get_billing_postcode(),
            'state' => $order->get_billing_state(),
            'city' => $order->get_billing_city(),
            'countryCode' => $order->get_billing_country(),
            'currency' => $order->get_currency(),
            'amount' => $order->get_total(),
            'invoice' => $order->get_order_number(),
            'description' => get_bloginfo('name'),
            'product' => $product
        ];


        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $this->api_url . '/api/payment/v2');

        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($field));
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type:application/json',
            'app-Key:' . $this->app_key
        ]);
        $response = curl_exec($ch);

        $url = json_decode($response, null);

        return array(
            'result' => 'success',
            'redirect' => $url->url
        );
    }
}


// Register the payment gateway
function add_custom_payment_gateway($methods)
{
    $methods[] = 'Custom_Payment_Gateway';
    return $methods;
}

add_filter('woocommerce_payment_gateways', 'add_custom_payment_gateway');
